import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import {
  csv,
  nest,
  scaleLinear,
  scaleTime,
  extent,
  invert
} from 'd3';
import { useData } from './useData.js';
import { Marks } from './Marks.js';

const width = 960;
const height = 500;
const margin = { top: 80, right: 0, bottom: 30, left: 0 };

const App = () => {
  const data = useData();


  if (!data) {
    return <pre></pre>;
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const lineValue = (d) => d.Jahr;

  //group the data
  const nested = nest().key(lineValue).entries(data);

  const xValue = (d) => d.Kalenderwoche;
  //const xAxisLabel = '';

  const yValue = (d) => d.Sterbefälle;
  //const yAxisLabel = '';

  const xScale = scaleLinear()
    .domain([0,52])
    .range([0, innerWidth])
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0]);
  
  return (
    <svg width={width} height={height}>
      <g
        transform={`translate(${margin.left - 13},${margin.top})`}
      >
        <text className="erklaerungen" x={355} y={4}>
          2.431 Sterbefälle zwischen 9. und 15.11.2020 |
          Höchstwert seit 42 Jahren - 
        </text>

        <text className="erklaerungen1" x={38} y={30}>
          - 2.340 Sterbefälle zwischen 9. und 15.01.2017 |
          starke Grippewelle 2016/17
        </text>

        <text className="erklaerungen1" x={867} y={77}>
          2.160 Sterbefälle
        </text>
        <text className="erklaerungen1" x={788} y={87}>
          zwischen 26.12.2016 und 01.01.2017
        </text>
        <text className="erklaerungen1" x={820} y={97}>
          starke Grippewelle 2016/17 -
        </text>

        <text className="title" x={innerWidth / 6} y={-30}>
          Sterbefälle in Österreich 2000 - 2020
        </text>
        
        <text className="source" x={38} y={400}>
					Gestorbene nach Kalenderwoche, Quelle: <a href="https://www.statistik.at/web_de/statistiken/menschen_und_gesellschaft/bevoelkerung/gestorbene/index.html">Statistik Austria</a>
        </text>
        <Marks
          data={nested[0].values}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.04}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[1].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.05}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[2].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.08}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[3].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.1}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[4].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.13}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[5].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.15}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[6].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.18}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[7].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.2}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[8].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.23}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[9].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.24}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[10].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.25}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[11].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.28}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[12].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.27}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[13].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.29}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[14].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.3}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[15].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.33}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[16].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.35}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[17].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.37}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[18].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.39}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[19].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={0.4}
          circleRadius={0}
          lineValue={lineValue}
        />
        <Marks
          data={nested[20].values}
          nested={nested}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          opacity={1}
          circleRadius={4}
          lineValue={lineValue}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootEle